@@ -1,23 +1,3 @@
-/* -copyright-
-#-# 
-#-# xsnow: let it snow on your desktop
-#-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022,2023,2024 Willem Vermin
-#-# 
-#-# This program is free software: you can redistribute it and/or modify
-#-# it under the terms of the GNU General Public License as published by
-#-# the Free Software Foundation, either version 3 of the License, or
-#-# (at your option) any later version.
-#-# 
-#-# This program is distributed in the hope that it will be useful,
-#-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-#-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#-# GNU General Public License for more details.
-#-# 
-#-# You should have received a copy of the GNU General Public License
-#-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-# 
- */
 /*
    This file is part of ``kdtree'', a library for working with kd-trees.
    Copyright (C) 2007-2011 John Tsiombikas <nuclear@member.fsf.org>
@@ -293,12 +273,12 @@ int kd_insert3f(struct kdtree *tree, float x, float y, float z, void *data)
 static int find_nearest(struct kdnode *node, const double *pos, double range, struct res_node *list, int ordered, int dim)
 {
    double dist_sq, dx;
-   int i, ret, added_res = 0;
+   int ret, added_res = 0;
 
    if(!node) return 0;
 
    dist_sq = 0;
-   for(i=0; i<dim; i++) {
+   for (int i=0; i<dim; i++) {
       dist_sq += SQ(node->pos[i] - pos[i]);
    }
    if(dist_sq <= SQ(range)) {
@@ -327,13 +307,13 @@ static int find_nearest(struct kdnode *node, const double *pos, double range, st
 static int find_nearest_n(struct kdnode *node, const double *pos, double range, int num, struct rheap *heap, int dim)
 {
    double dist_sq, dx;
-   int i, ret, added_res = 0;
+   int ret, added_res = 0;
 
    if(!node) return 0;
 
    /* if the photon is close enough, add it to the result heap */
    dist_sq = 0;
-   for(i=0; i<dim; i++) {
+   for (int i=0; i<dim; i++) {
       dist_sq += SQ(node->pos[i] - pos[i]);
    }
    if(dist_sq <= range_sq) {
@@ -376,7 +356,6 @@ static int find_nearest_n(struct kdnode *node, const double *pos, double range,
 static void kd_nearest_i(struct kdnode *node, const double *pos, struct kdnode **result, double *result_dist_sq, struct kdhyperrect* rect)
 {
    int dir = node->dir;
-   int i;
    double dummy, dist_sq;
    struct kdnode *nearer_subtree, *farther_subtree;
    double *nearer_hyperrect_coord, *farther_hyperrect_coord;
@@ -408,7 +387,7 @@ static void kd_nearest_i(struct kdnode *node, const double *pos, struct kdnode *
    /* Check the distance of the point at the current node, compare it
     * with our best so far */
    dist_sq = 0;
-   for(i=0; i < rect->dim; i++) {
+   for (int i=0; i < rect->dim; i++) {
       dist_sq += SQ(node->pos[i] - pos[i]);
    }
    if (dist_sq < *result_dist_sq) {
@@ -438,7 +417,6 @@ struct kdres *kd_nearest(struct kdtree *kd, const double *pos)
    struct kdnode *result;
    struct kdres *rset;
    double dist_sq;
-   int i;
 
    if (!kd) return NULL;
    if (!kd->rect) return NULL;
@@ -463,7 +441,7 @@ struct kdres *kd_nearest(struct kdtree *kd, const double *pos)
    /* Our first guesstimate is the root node */
    result = kd->root;
    dist_sq = 0;
-   for (i = 0; i < kd->dim; i++)
+   for (int i = 0; i < kd->dim; i++)
       dist_sq += SQ(result->pos[i] - pos[i]);
 
    /* Search for the nearest neighbour recursively */
@@ -686,8 +664,7 @@ void *kd_res_itemf(struct kdres *rset, float *pos)
 {
    if(rset->riter) {
       if(pos) {
-	 int i;
-	 for(i=0; i<rset->tree->dim; i++) {
+	 for (int i=0; i<rset->tree->dim; i++) {
 	    pos[i] = rset->riter->item->pos[i];
 	 }
       }
@@ -764,9 +741,7 @@ static struct kdhyperrect* hyperrect_duplicate(const struct kdhyperrect *rect)
 
 static void hyperrect_extend(struct kdhyperrect *rect, const double *pos)
 {
-   int i;
-
-   for (i=0; i < rect->dim; i++) {
+   for (int i=0; i < rect->dim; i++) {
       if (pos[i] < rect->min[i]) {
 	 rect->min[i] = pos[i];
       }
@@ -778,10 +753,9 @@ static void hyperrect_extend(struct kdhyperrect *rect, const double *pos)
 
 static double hyperrect_dist_sq(struct kdhyperrect *rect, const double *pos)
 {
-   int i;
    double result = 0;
 
-   for (i=0; i < rect->dim; i++) {
+   for (int i=0; i < rect->dim; i++) {
       if (pos[i] < rect->min[i]) {
 	 result += SQ(rect->min[i] - pos[i]);
       } else if (pos[i] > rect->max[i]) {
